pub struct UncompiledPage(pub SourcePage);Expand description
Newtype marking a SourcePage that has not yet been parsed.
Illegal transitions (e.g. writing directly to disk) are prevented because
only CompiledPage and RenderedPage expose HTML payloads.
Tuple Fields
0: SourcePageImplementations
Sourceimpl UncompiledPage
impl UncompiledPage
Sourcepub fn new(page: SourcePage) -> Self
pub fn new(page: SourcePage) -> Self
Wraps a discovered source page for the parsing stage.
Sourcepub fn inner(&self) -> &SourcePage
pub fn inner(&self) -> &SourcePage
Borrows the inner source page.
Sourcepub fn into_inner(self) -> SourcePage
pub fn into_inner(self) -> SourcePage
Consumes the wrapper and returns the inner source page.